@@ -104,6 +104,7 @@ from scalyr_agent.profiler import ScalyrProfiler
 from scalyr_agent.scalyr_client import ScalyrClientSession
 from scalyr_agent.scalyr_client import create_client, verify_server_certificate
 from scalyr_agent.copying_manager import CopyingManager
+from scalyr_agent.monitors_manager import set_monitors_manager
 from scalyr_agent.configuration import Configuration
 from scalyr_agent.util import RunState, ScriptEscalator
 from scalyr_agent.util import warn_on_old_or_unsupported_python_version
@@ -120,6 +121,7 @@ from scalyr_agent.platform_controller import (
 from scalyr_agent.platform_controller import AgentNotRunning
 from scalyr_agent.build_info import get_build_revision
 from scalyr_agent import compat
+import scalyr_agent.monitors_manager
 
 
 STATUS_FILE = "last_status"
@@ -1124,7 +1126,9 @@ class ScalyrAgent(object):
                     agent_log_file_path=AGENT_LOG_FILENAME,
                 )
 
-                self.__update_debug_log_level(self.__config.debug_level)
+                self.__update_debug_log_level(
+                    self.__config.debug_level, self.__config.debug_level_logger_names
+                )
 
                 # We record where the log files(including multiprocess worker sessions logs) currently are
                 # so that we can (in the worse case) start copying them from those position.
@@ -1167,6 +1171,8 @@ class ScalyrAgent(object):
                     wt.monitors_manager.set_user_agent_augment_callback(
                         wt.copying_manager.augment_user_agent_for_workers_sessions
                     )
+                    # configure currently active monitor manager instance variable
+                    set_monitors_manager(monitors_manager=wt.monitors_manager)
                     wt.start(logs_initial_positions)
                     return wt, wt.copying_manager, wt.monitors_manager
 
@@ -1528,7 +1534,7 @@ class ScalyrAgent(object):
             print("%s" % six.text_type(e), file=sys.stderr)
             sys.exit(4)
 
-    def __update_debug_log_level(self, debug_level):
+    def __update_debug_log_level(self, debug_level, debug_level_logger_names=None):
         """Updates the debug log level of the agent.
         @param debug_level: The debug level, ranging from 0 (no debug) to 5.
 
@@ -1543,7 +1549,9 @@ class ScalyrAgent(object):
             scalyr_logging.DEBUG_LEVEL_5,
         ]
 
-        scalyr_logging.set_log_level(levels[debug_level])
+        scalyr_logging.set_log_level(
+            level=levels[debug_level], debug_level_logger_names=debug_level_logger_names
+        )
 
     def __create_new_client(self):
         result = None
