@@ -193,6 +193,18 @@ class ScalyrMonitor(StoppableThread):
 
         StoppableThread.__init__(self, name="metric thread")
 
+    @property
+    def uid(self):
+        """
+        Return unique id for this monitor.
+
+        Unique ID is composed of the monitor name and the id specified in the monitor local config.
+        """
+        return (
+            self._config["module"] + "-" + str(self._config.get("id", "default"))
+            or "default"
+        )
+
     def _initialize(self):
         """Can be overridden by derived classes to perform initialization functions before the monitor is run.
 
@@ -429,7 +441,7 @@ class ScalyrMonitor(StoppableThread):
             else:
                 max_bytes = 20 * 1024 * 1024
 
-        return (rotation_count, max_bytes)
+        return (int(rotation_count), int(max_bytes))
 
     def open_metric_log(self):
         """Opens the logger for this monitor.
